import { defineComponent, toRefs, reactive, onMounted, ref } from 'vue'

// import classes from './index.module.less'
import styles from './index.module.less'
import hotSearch from '@/components/hotSearch'
import searchInput from '@/components/searchInput'
import videoDetailItem from '@/components/videoDetailItem'
import request from '@/helpers/request'
import pagination from '@/components/pagination'
export default defineComponent({
  name: 'videoDetailList',
  props: {
    title: {
      type: String,
      default: ''
    }
  },
  components: {
    hotSearch,
    searchInput,
    videoDetailItem,
    pagination
  },
  setup(props, conent) {
    const state = reactive({
      title: props.title,
      videoList: [],
      searchs: { search: '', lessonSubject: '' },

      pageInfo: {
        // 分页规则
        limit: 9, // 限制显示条数
        page: 1, // 当前页
        total: 0, // 总条数
        page_size: [9, 20, 40, 50] // 选择限制显示条数
      }
    })

    const getVideoList = async () => {
      try {
        const res = await request.post(
          '/api-website/open/videoLessonGroup/page',
          {
            data: {
              ...state.searchs,
              albumStatus: 'PASS',
              page: state.pageInfo.page,
              rows: state.pageInfo.limit
            }
          }
        )
        state.videoList = res.data.rows
        state.pageInfo.total = res.data.total
      } catch (e) {
        console.log(e)
      }
    }

    const gotoSearch = (val: string) => {
      console.log(val)
      state.searchs.search = val
    }
    const startSearch = (val: any) => {
      console.log(val,'valstartSearch')
      state.searchs = {
        ...state.searchs,
        lessonSubject: val.subject,
        search: val.search
      }
      getVideoList()
    }
    onMounted(() => {
      getVideoList()
    })
    return () => (
      <>
        <div>
          <div class="wall" style={{ height: '70px' }}></div>
          <div class={styles.w1200}>
            <div class={styles.section}>
              <searchInput
                isWhile={true}
                // searchVal={state.searchs.search}
                onStartSearch={(val: any) => {
                  startSearch(val)
                }}
              ></searchInput>
              <hotSearch
                onHotTag={(val: string) => {
                  gotoSearch(val)
                }}
                type={''}
              ></hotSearch>
            </div>
            <div class={styles.videoList}>
              {state.videoList.map(item => {
                return <videoDetailItem detail={item}></videoDetailItem>
              })}
            </div>
            <pagination
              total={state.pageInfo.total}
              v-model:page={state.pageInfo.page}
              v-model:limit={state.pageInfo.limit}
              pageSizes={state.pageInfo.page_size}
              pagination={getVideoList}
            />
          </div>
        </div>
      </>
    )
  }
})
