import {
  defineComponent,
  toRefs,
  reactive,
  onMounted,
  ref,
  nextTick
} from 'vue'

// import classes from './index.module.less'
import detaile from '@/components/videoDetailItem/images/detaile.png'
import videoCourseItem from './modals/videoCourseItem'
import courseIcon from './images/courseIcon.png'
import peopleIcon from './images/peopleIcon.png'
import teacherIcon from './images/teacherIcon.png'
import player from './images/player.png'
import teacher from './images/teacher.png'
import teacherHeader from '@/common/images/icon_teacher.png'
import musiceIcon from './images/musiceIcon.png'
import TimetableIcon from './images/TimetableIcon.png'
import styles from './index.module.less'
import videoDetailItem from '@/components/videoDetailItem'
import colVideo from '@/components/col-video/index'
import request from '@/helpers/request'
import pagination from '@/components/pagination'
import { useRoute } from 'vue-router'
import { getUserInfo, getUserType, getAuth } from '@/helpers/utils'
export default defineComponent({
  name: 'videoDetailList',
  props: {
    title: {
      type: String,
      default: ''
    }
  },
  components: {
    videoDetailItem,
    videoCourseItem,
    pagination,
    colVideo
  },
  setup(props, conent) {
    const state = reactive({
      title: props.title,
      videoList: [],
      videoDetail: {
        auditId: 0,
        auditName: '',
        auditStatus: '',
        auditVersion: '',
        avatar: '',
        countStudent: 0,
        createTime: '',
        hotFlag: 0,
        id: 0,
        lessonCount: 0,
        lessonCoverUrl: '',
        lessonDesc: '',
        lessonName: '',
        lessonPrice: 0,
        lessonSubject: '',
        lessonSubjectName: '',
        lessonTag: '',
        realName: '',
        sortNumber: 0,
        teacherId: 0,
        topFlag: 0,
        updateTime: '',
        username: ''
      },
      otherVideoList: [],
      teacherDetail: {} as any,
      id: '',
      pageInfo: {
        // 分页规则
        limit: 5, // 限制显示条数
        page: 1, // 当前页
        total: 0, // 总条数
        page_size: [5, 20, 40, 50] // 选择限制显示条数
      },
      userType: ''
    })

    const route = useRoute()
    const getVideoList = async () => {
      try {
        const res = await request.post(
          '/api-website/open/videoLessonGroup/info/page',
          {
            data: {
              auditStatus: 'PASS',
              videoLessonGroupId: state.id,
              page: state.pageInfo.page,
              rows: state.pageInfo.limit
            }
          }
        )
        state.videoList = res.data.rows
        state.pageInfo.total = res.data.total
      } catch (e) {
        console.log(e)
      }
    }
    const getVideoDetail = async () => {
      try {
        const res = await request.get(
          '/api-website/open/videoLessonGroup/selectVideoLesson',
          {
            params: {
              groupId: state.id
            }
          }
        )
        state.videoDetail = { ...res.data.lessonGroup }
        const teacherRes = await request.get(
          `/api-website/open/teacher/detail/${res.data.lessonGroup.teacherId}`
        )
        state.teacherDetail = { ...teacherRes.data }
      } catch (e) {}
    }

    const getOther = async () => {
      try {
        const res = await request.post(
          '/api-website/open/videoLessonGroup/otherLesson',
          {
            data: {
              videoLessonGroupId: state.id
            }
          }
        )
        state.otherVideoList = res.data
      } catch (e) {
        console.log(e)
      }
    }

    const getDetail = (val: string) => {
      state.id = val
      nextTick(() => {
        _init()
      })
    }
    const _init = () => {
      getVideoList()
      setTimeout(() => {
        getVideoDetail()
      }, 100)
      setTimeout(() => {
        getOther()
      }, 150)
    }
    const followVideo = async () => {
      try {
        const res = await request.get('/api-website/student/starOrUnStar', {
          params: {
            userId: state.teacherDetail.userId,
            starStatus: state.teacherDetail.isStar ? 0 : 1
          }
        })
        _init()
        // state.otherVideoList = res.data
      } catch (e) {
        console.log(e)
      }
    }
    onMounted(() => {
      if (route.query.id) {
        state.id = route.query.id as string
      }
      state.userType = getUserType()
      _init()
    })
    return () => (
      <>
        <div>
          <div class="wall" style={{ height: '70px' }}></div>
          <div class={[styles.w1200, styles.detailWrap]}>
            <div class={styles.detailLeft}>
              <img
                src={
                  state.videoDetail.lessonCoverUrl
                    ? state.videoDetail.lessonCoverUrl
                    : detaile
                }
                class={styles.detailTopImg}
                alt=""
              />
              <div class={styles.courseWrap}>
                <div class={styles.courseTitle}>
                  <img src={courseIcon} alt="" />
                  <span>课程介绍</span>
                </div>
                <div class={styles.courseInfo}>
                  <p>{state.videoDetail.lessonDesc}</p>
                </div>
                {/* courseList */}
                <div class={styles.courseListWrap}>
                  <div class={styles.courseTitle}>
                    <div class={styles.courseTitleLeft}>
                      <img src={TimetableIcon} alt="" />
                      <span>课程列表</span>
                    </div>
                    <span class={styles.courseTitlTimer}>
                      共{state.videoDetail.lessonCount}课时
                    </span>
                  </div>
                  {state.videoList.map(item => {
                    return <videoCourseItem item={item}></videoCourseItem>
                  })}
                </div>
              </div>
              <pagination
                total={state.pageInfo.total}
                v-model:page={state.pageInfo.page}
                v-model:limit={state.pageInfo.limit}
                pageSizes={state.pageInfo.page_size}
                pagination={getVideoList}
              />
            </div>
            <div class={styles.detailRight}>
              <div class={styles.teacherInfo}>
                <div class={styles.teacherHeadWrap}>
                  <div class={styles.teacherHeadLeft}>
                    <img
                      src={
                        state.videoDetail.avatar
                          ? state.videoDetail.avatar
                          : teacherHeader
                      }
                      alt=""
                      class={styles.teacherHeader}
                    />
                    <div class={styles.teacherHeadInfo}>
                      <div class={styles.teacherHeadName}>
                        <span>{state.videoDetail.username}</span>
                        {state.teacherDetail.teacherType &&
                        state.teacherDetail.teacherType.indexOf('ENTRY') ==
                          -1 ? (
                          ''
                        ) : (
                          <img
                            src={teacher}
                            class={styles.teacherIcon}
                            alt=""
                          />
                        )}
                        {state.teacherDetail.teacherType &&
                        state.teacherDetail.teacherType.indexOf('MUSICIAN') ==
                          -1 ? (
                          ''
                        ) : (
                          <img
                            src={musiceIcon}
                            class={styles.teacherIcon}
                            alt=""
                          />
                        )}
                      </div>
                      <p class={styles.fens}>
                        粉丝 <span>{state.teacherDetail.fansNum}</span>
                      </p>
                    </div>
                  </div>
                  {state.userType == 'STUDENT' ? (
                    <div
                      class={[
                        styles.teacherHeadRight,
                        state.teacherDetail.isStar ? styles.isStart : ''
                      ]}
                      onClick={() => followVideo()}
                    >
                      {state.teacherDetail.isStar ? '已关注' : '关注'}
                    </div>
                  ) : null}
                </div>
                <div class={styles.titleWrap}>
                  <img src={peopleIcon} alt="" />
                  <span>个人介绍</span>
                </div>
                <p class={styles.teacherDetail}>
                  {state.teacherDetail.introduction}
                </p>
                <div class={styles.titleWrap}>
                  <img src={teacherIcon} alt="" />
                  <span>老师风采</span>
                </div>
                <div class={styles.teacherVideoList}>
                  {state.teacherDetail.styleVideo &&
                    state.teacherDetail.styleVideo.map((item: any) => {
                      return (
                        <div class={styles.videoItem}>
                          <colVideo
                            styleValue={{ with: '218px', height: '145px' }}
                            controls={true}
                            src={item.videoUrl}
                            class={styles.videoItemVideo}
                          />

                          {/* <img src={player} alt="" class={styles.player} /> */}
                        </div>
                      )
                    })}

                  {/* <div class={styles.videoItem}>
                    <img src={detaile} alt="" class={styles.Styles} />
                    <img src={player} alt="" class={styles.player} />
                  </div> */}
                </div>
              </div>
              <div class={styles.otherCourse}>
                <h2>其他课程</h2>
                <div>
                  {state.otherVideoList.map(item => {
                    return (
                      <videoDetailItem
                        detail={item}
                        isFull={true}
                        onGetDetail={val => {
                          getDetail(val)
                        }}
                      ></videoDetailItem>
                    )
                  })}

                  {/* videoDetailItem */}
                </div>
              </div>
            </div>
          </div>
        </div>
      </>
    )
  }
})
